.. mellon documentation master file, created by
   sphinx-quickstart on Fri Sep 16 22:07:21 2022.

.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Modules:

   Model <model>
   Predictor <predictor>
   Serialization <serialization>
   Utilities <util>
   Validation <validation>
   Covariance Functions <cov>
   Parameter Selection <parameters>
   Inference <inference>

.. toctree::
   :hidden:
   :caption: Tutorials:

   notebooks/basic_tutorial.ipynb
   notebooks/trajectory-trends_tutorial.ipynb
   notebooks/gene_change_analysis_tutorial.ipynb
   notebooks/time-series_tutorial.ipynb

.. include:: ../../README.rst

.. toctree::
   :hidden:
   :caption: Links:

    Setty Lab <http://setty-lab.org>
    Github Repo <https://github.com/settylab/mellon>


Index
=====

* :ref:`genindex`
